import { GqlAttributeModel } from "./entity";
export declare type EntityMessages<K extends string = string> = {
    [P in K]: EntityMessages | string;
};
/**
 * Generate messages that should be added to app message pack (en.ts)
 * for translate entity resource name and fields.
 * Generated messages based on information from graphQL query - entity name and attributes.
 *
 * @param entityName - entity name string.
 * If entity name ends with 'Dto' or 'DTO' - this suffix will be removed in 'name' message.
 * @param attributes - graphQL attributes from graphQL query as GqlAttributeModel[], example:
 * [{
 *    name: "key",
 *    displayName: "value",
 * }]
 *
 * @returns messages as typescript object (react-admin i18n format),
 * which contains resource name and fields:
 * {
 *   Entity: {
 *     name: "Entity |||| Entities",
 *     fields: {
 *       key: "value",
 *     },
 * }
 *
 * Note: react-admin used `||||` as separator between singular and plural name forms.
 *
 */
export declare function getEntityMessages(entityName: string, attributes: GqlAttributeModel[]): EntityMessages;
