"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const getEntityMessages_1 = require("./getEntityMessages");
describe("getEntityMessages", () => {
    it("should create messages for entity without fields", () => {
        const result = getEntityMessages_1.getEntityMessages("Entity", []);
        const expected = {
            Entity: {
                name: "Entity |||| Entities",
                fields: {},
            },
        };
        chai_1.expect(result).to.deep.equal(expected);
    });
    it("should create messages for entity with one field", () => {
        const result = getEntityMessages_1.getEntityMessages("Entity", [
            {
                name: "key",
                displayName: "value",
            },
        ]);
        const expected = {
            Entity: {
                name: "Entity |||| Entities",
                fields: {
                    key: "value",
                },
            },
        };
        chai_1.expect(result).to.deep.equal(expected);
    });
    it("should create messages for entity with two fields", () => {
        const result = getEntityMessages_1.getEntityMessages("Entity", [
            {
                name: "key1",
                displayName: "value1",
            },
            {
                name: "key2",
                displayName: "value2",
            },
        ]);
        const expected = {
            Entity: {
                name: "Entity |||| Entities",
                fields: {
                    key1: "value1",
                    key2: "value2",
                },
            },
        };
        chai_1.expect(result).to.deep.equal(expected);
    });
    it("should remove 'Dto' suffix from entity name, when creating message value for 'name'", () => {
        chai_1.expect(getEntityMessages_1.getEntityMessages("EntityDto", [])).to.deep.equal({
            EntityDto: {
                name: "Entity |||| Entities",
                fields: {},
            },
        });
        chai_1.expect(getEntityMessages_1.getEntityMessages("EntityDTO", [])).to.deep.equal({
            EntityDTO: {
                name: "Entity |||| Entities",
                fields: {},
            },
        });
    });
    it("should not remove 'Dto', if full entity name is 'Dto'", function () {
        chai_1.expect(getEntityMessages_1.getEntityMessages("Dto", [])).to.deep.equal({
            Dto: {
                name: "Dto |||| Dtos",
                fields: {},
            },
        });
    });
    it("should not replace 'Dto' in the middle of entity name", function () {
        chai_1.expect(getEntityMessages_1.getEntityMessages("EntityDtoOne", [])).to.deep.equal({
            EntityDtoOne: {
                name: "EntityDtoOne |||| EntityDtoOnes",
                fields: {},
            },
        });
    });
});
//# sourceMappingURL=getEntityMessages.test.js.map