"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeI18nMessagesWithLocaleFileContent = exports.mergeI18nMessagesWithLocaleFile = void 0;
const deepmerge_1 = __importDefault(require("deepmerge"));
const fs = __importStar(require("fs/promises"));
const jscodeshift_1 = __importDefault(require("jscodeshift"));
const path = __importStar(require("path"));
const parseTs_1 = require("../../../building-blocks/util/parseTs");
/**
 * Find locale file by localeName in file system of generated app
 * then find variable with localeMessages by localeName
 * then find "resources" property inside variable, if there is no 'resource' property - create it
 * then merge default messages with existing messages to locale file in file system
 *
 * @param localeMessagesPath - path of i18n messages dir
 * @param localeName - using to get locale file in i18n messages dir and find variable with locale messages inside
 * @param defaultMessages - messages that should by in generated app, them can be overridden later in generated app
 */
async function mergeI18nMessagesWithLocaleFile(localeMessagesPath, localeName, defaultMessages) {
    const localePath = path.join(localeMessagesPath, `${localeName}.ts`);
    const localeFile = await fs.readFile(localePath, "utf-8")
        .catch(() => {
        throw new Error(`File with '${localeName}' locale not found in '${localeMessagesPath}' dir`);
    });
    const localeFileContent = mergeI18nMessagesWithLocaleFileContent(localeFile, localeName, defaultMessages);
    await fs.writeFile(localePath, localeFileContent, "utf-8");
}
exports.mergeI18nMessagesWithLocaleFile = mergeI18nMessagesWithLocaleFile;
/**
 * Take localeFileContent
 * then find variable with localeMessages by localeName
 * then find "resources" property inside variable, if there is no 'resource' property - create it
 * then merge default messages with existing messages to locale file in file system
 *
 * @param localeFileContent - string version of locale file from generated app
 * @param localeName - using to find variable with locale messages inside
 * @param defaultMessages - messages that should by in generated app, them can be overridden later in generated app
 * @returns localeFileContent with added default messages which was missed before
 */
function mergeI18nMessagesWithLocaleFileContent(localeFileContent, localeName, defaultMessages) {
    const source = parseTs_1.parseTs(localeFileContent);
    const localeVariable = source.findVariableDeclarators(localeName);
    if (localeVariable.length === 0) {
        throw new Error(`${localeName} variable not found in file with ${localeName} locale`);
    }
    const hasResourcesProperty = localeVariable.find(jscodeshift_1.default.ObjectProperty, { key: { name: "resources" } }).length !== 0;
    // localeVariable in locale file could have "resources" property,
    // if not - we add it with empty object value
    if (!hasResourcesProperty) {
        localeVariable.find(jscodeshift_1.default.ObjectExpression).forEach(path => {
            path.node.properties.push(jscodeshift_1.default.objectProperty(jscodeshift_1.default.identifier("resources"), jscodeshift_1.default.objectExpression([])));
        });
    }
    const resourcesProperty = localeVariable.find(jscodeshift_1.default.ObjectProperty, {
        key: { name: "resources" }
    });
    resourcesProperty.replaceWith((resourcePropertyPath) => {
        const resourcePropertyValue = resourcePropertyPath.node.value;
        // Find "resources" property take existing messages and merge them with default messages.
        // Existing messages have more priority.
        return jscodeshift_1.default.objectProperty(jscodeshift_1.default.identifier("resources"), parseMessagesToNode(deepmerge_1.default(defaultMessages, parseNodeToMessages(resourcePropertyValue) || {})));
    });
    return source.toSource();
}
exports.mergeI18nMessagesWithLocaleFileContent = mergeI18nMessagesWithLocaleFileContent;
/**
 * Existed messages in `en.ts` should be parsed to node for subsequent merge with new messages.
 * @param messages
 */
function parseMessagesToNode(messages) {
    return jscodeshift_1.default.objectExpression(Object.keys(messages).map(key => {
        const value = typeof messages[key] === "string"
            ? jscodeshift_1.default.literal(messages[key]) : parseMessagesToNode(messages[key]);
        return jscodeshift_1.default.objectProperty(jscodeshift_1.default.identifier(key), value);
    }));
}
/**
 * parse AST node to messages
 * @param node ast node
 */
// TODO - try to get rid of "undefined" in return statement
function parseNodeToMessages(node) {
    // node is object property
    if (jscodeshift_1.default.ObjectProperty.check(node)) {
        // TODO - not sure that message key could be "unknown"
        const messageKey = jscodeshift_1.default.Identifier.check(node.key) ? node.key.name : "unknown";
        let messageValue;
        // node is Literal
        if (jscodeshift_1.default.Literal.check(node.value)) {
            messageValue = typeof node.value.value === "string" ? node.value.value : "unknown";
            // TODO which type of node is here?
        }
        else {
            messageValue = parseNodeToMessages(node.value) || "unknown";
        }
        return { [messageKey]: messageValue };
    }
    // node is object expression - recursive parsing for nested nodes
    if (jscodeshift_1.default.ObjectExpression.check(node)) {
        return node.properties.reduce((acc, cur) => ({ ...acc, ...parseNodeToMessages(cur) }), {});
    }
    // TODO what we should do in this case?
}
//# sourceMappingURL=mergeI18nMessagesWithLocaleFile.js.map