"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = __importStar(require("chai"));
const chai_as_promised_1 = __importDefault(require("chai-as-promised"));
const mergeI18nMessagesWithLocaleFile_1 = require("./mergeI18nMessagesWithLocaleFile");
chai_1.default.use(chai_as_promised_1.default);
describe("mergeI18nMessagesWithLocaleFile", async () => {
    it("should throw error if file with locale not found", async () => {
        await chai_1.expect(mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFile("/notExistentPath", "en", {})).to.be.rejectedWith("File with 'en' locale not found in '/notExistentPath' dir");
    });
});
describe("mergeI18nMessagesWithLocaleFileContent", async () => {
    it("should add 'resources' object to messages file without resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {}
    }`;
        const localeResult = mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFileContent(locale, "en", {});
        chai_1.expect(localeResult).to.deep.equal(localeExpected);
    });
    it("should add 'resources' object and messages to locale without resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,

      resources: {
        AnyDTO: {
          newField: "newValue"
        }
      }
    }`;
        const localeResult = mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFileContent(locale, "en", {
            AnyDTO: {
                newField: "newValue",
            },
        });
        chai_1.expect(localeResult).to.deep.equal(localeExpected);
    });
    it("should add messages to locale with resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {}
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {
        AnyDTO: {
          newField: "newValue"
        }
      }
    }`;
        const localeResult = mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFileContent(locale, "en", {
            AnyDTO: {
                newField: "newValue",
            },
        });
        chai_1.expect(localeResult).to.deep.equal(localeExpected);
    });
    it("should merge messages and leave old ones unmodified to locale with resources", () => {
        const locale = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {
        AnyDTO: {
          oldTouchedField: "oldValue",
          oldUntouchedField: "oldValue",
        }
      }
    }`;
        const localeExpected = `
    export const en: TranslationMessages = {
      ...englishMessages,
      resources: {
        AnyDTO: {
          newField: "newValue",
          oldTouchedField: "oldValue",
          oldUntouchedField: "oldValue"
        }
      }
    }`;
        const localeResult = mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFileContent(locale, "en", {
            AnyDTO: {
                newField: "newValue",
                oldTouchedField: "newValue",
            },
        });
        chai_1.expect(localeResult).to.deep.equal(localeExpected);
    });
    it("should throw error if variable with locale not found", async () => {
        const locale = `
    export const notEn: TranslationMessages = {
      ...englishMessages,
    }`;
        chai_1.should().throw(() => mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFileContent(locale, "en", {}), "en variable not found in file with en locale");
    });
});
//# sourceMappingURL=mergeI18nMessagesWithLocaleFile.test.js.map